diff --git a/GUI/Model/Beam/BeamAngleItems.cpp b/GUI/Model/Beam/BeamAngleItems.cpp
index e225e11edfe31c77cdc173dea672f56ac5b30acb..b0fc8655d4d9d6f15da8f65c8a1638d0ffa9939f 100644
--- a/GUI/Model/Beam/BeamAngleItems.cpp
+++ b/GUI/Model/Beam/BeamAngleItems.cpp
@@ -19,7 +19,7 @@
 
 BeamAzimuthalAngleItem::BeamAzimuthalAngleItem()
 {
-    m_distribution.initWithInitializer("Distribution", "", DistributionsCatalog::types(),
+    m_distribution.initWithInitializer("Distribution", "", DistributionCatalog::types(),
                                        initDistribution);
 }
 
@@ -59,7 +59,7 @@ double BeamAzimuthalAngleItem::scaleFactor() const
 
 BeamInclinationAngleItem::BeamInclinationAngleItem()
 {
-    m_distribution.initWithInitializer("Distribution", "", DistributionsCatalog::types(),
+    m_distribution.initWithInitializer("Distribution", "", DistributionCatalog::types(),
                                        initDistribution);
 }
 
diff --git a/GUI/Model/Beam/BeamDistributionItem.h b/GUI/Model/Beam/BeamDistributionItem.h
index 84d7e94cdae7de4fc385308ec97cc73a61e7a3b7..c13c83d3b3d347ef9ebe17c1dbbe41c6d61b8793 100644
--- a/GUI/Model/Beam/BeamDistributionItem.h
+++ b/GUI/Model/Beam/BeamDistributionItem.h
@@ -15,7 +15,7 @@
 #ifndef BORNAGAIN_GUI_MODEL_BEAM_BEAMDISTRIBUTIONITEM_H
 #define BORNAGAIN_GUI_MODEL_BEAM_BEAMDISTRIBUTIONITEM_H
 
-#include "GUI/Model/Beam/DistributionsCatalog.h"
+#include "GUI/Model/Beam/DistributionCatalog.h"
 #include "GUI/Model/Descriptor/PolyItem.h"
 #include "Param/Distrib/ParameterDistribution.h"
 
@@ -37,12 +37,12 @@ public:
     virtual double scaleFactor() const;
 
     DistributionItem* distributionItem() const { return m_distribution.certainItem(); }
-    PolyItem<DistributionsCatalog>& distributionSelection() { return m_distribution; }
+    PolyItem<DistributionCatalog>& distributionSelection() { return m_distribution; }
 
     virtual std::unique_ptr<IDistribution1D> createDistribution1D() const;
 
 protected:
-    PolyItem<DistributionsCatalog> m_distribution;
+    PolyItem<DistributionCatalog> m_distribution;
 };
 
 #endif // BORNAGAIN_GUI_MODEL_BEAM_BEAMDISTRIBUTIONITEM_H
diff --git a/GUI/Model/Beam/BeamWavelengthItem.cpp b/GUI/Model/Beam/BeamWavelengthItem.cpp
index edca8591bd7caafc592c5925c54e6d79fa5a4f0a..e490080928cc54140209e8140bd6ff5c88642136 100644
--- a/GUI/Model/Beam/BeamWavelengthItem.cpp
+++ b/GUI/Model/Beam/BeamWavelengthItem.cpp
@@ -43,8 +43,8 @@ BeamWavelengthItem::BeamWavelengthItem(bool onlySymmetricDistributions)
 {
     m_distribution.initWithInitializer("Distribution", "",
                                        onlySymmetricDistributions
-                                           ? DistributionsCatalog::symmetricTypes()
-                                           : DistributionsCatalog::types(),
+                                           ? DistributionCatalog::symmetricTypes()
+                                           : DistributionCatalog::types(),
                                        initDistribution);
 }
 
diff --git a/GUI/Model/Beam/GrazingScanItem.cpp b/GUI/Model/Beam/GrazingScanItem.cpp
index 0481d8048ced7a31b413c563f6728ea26063d5f3..752cef1d3de51d16f4b873e7061fd6f7b812d2a1 100644
--- a/GUI/Model/Beam/GrazingScanItem.cpp
+++ b/GUI/Model/Beam/GrazingScanItem.cpp
@@ -67,7 +67,7 @@ GrazingScanItem::GrazingScanItem()
     : BeamDistributionItem()
     , m_current_axis_is_uniform_axis(true)
 {
-    m_distribution.initWithInitializer("Distribution", "", DistributionsCatalog::symmetricTypes(),
+    m_distribution.initWithInitializer("Distribution", "", DistributionCatalog::symmetricTypes(),
                                        initDistribution);
 
     m_uniform_alpha_axis = std::make_unique<BasicAxisItem>();
diff --git a/GUI/Model/FromCore/ItemizeSimulation.cpp b/GUI/Model/FromCore/ItemizeSimulation.cpp
index 339766aff135738aab7a21f45cfd3a32c6427d2a..23f752f3b75726560d31947e33eeb7f7861b5dce 100644
--- a/GUI/Model/FromCore/ItemizeSimulation.cpp
+++ b/GUI/Model/FromCore/ItemizeSimulation.cpp
@@ -131,7 +131,7 @@ void setMaskStacks(DetectorItem* detector_item, const IDetector& detector)
 void setDistributionTypeAndPars(BeamDistributionItem* pdi, const IDistribution1D* d)
 {
     const double factor = 1 / pdi->scaleFactor();
-    PolyItem<DistributionsCatalog>& di = pdi->distributionSelection();
+    PolyItem<DistributionCatalog>& di = pdi->distributionSelection();
 
     if (const auto* dd = dynamic_cast<const DistributionGate*>(d)) {
         auto* item = di.createCertainItem<DistributionGateItem>();
diff --git a/GUI/Model/Job/JobItem.h b/GUI/Model/Job/JobItem.h
index 99488ed3318dbde4f61de640a1b9a6e7cf708571..de9789d662736c6b8cb8ba78be1f75627b8fbbc6 100644
--- a/GUI/Model/Job/JobItem.h
+++ b/GUI/Model/Job/JobItem.h
@@ -16,7 +16,7 @@
 #define BORNAGAIN_GUI_MODEL_JOB_JOBITEM_H
 
 #include "GUI/Model/Descriptor/PolyItem.h"
-#include "GUI/Model/Sim/InstrumentsCatalog.h"
+#include "GUI/Model/Sim/InstrumentCatalog.h"
 #include <QThread>
 
 class BatchInfo;
@@ -129,7 +129,7 @@ private:
     std::unique_ptr<SimulationOptionsItem> m_simulation_options_item;
     std::unique_ptr<ParameterContainerItem> m_parameter_container;
     std::unique_ptr<SampleItem> m_sample_item;
-    PolyItem<InstrumentsCatalog> m_instrument;
+    PolyItem<InstrumentCatalog> m_instrument;
     std::unique_ptr<BatchInfo> m_batch_info;
     QString m_activity;
     std::unique_ptr<DataItem> m_simulated_data_item;
diff --git a/GUI/Model/Job/ParameterTreeBuilder.cpp b/GUI/Model/Job/ParameterTreeBuilder.cpp
index ced6797b172230ac27dda320644efe2f49f6b015..0b2db692f947a50ea198c839bdabe43bbb091715 100644
--- a/GUI/Model/Job/ParameterTreeBuilder.cpp
+++ b/GUI/Model/Job/ParameterTreeBuilder.cpp
@@ -253,7 +253,7 @@ ParameterLabelItem* ParameterTreeBuilder::addItemWithParticles(ParameterLabelIte
                                                                bool enableAbundance,
                                                                bool enablePosition)
 {
-    auto* label = addLabel<ParticlesCatalog>(parentLabel, p);
+    auto* label = addLabel<ParticleCatalog>(parentLabel, p);
 
     if (enableAbundance)
         addParameterItem(label, p->abundance());
@@ -263,7 +263,7 @@ ParameterLabelItem* ParameterTreeBuilder::addItemWithParticles(ParameterLabelIte
 
     if (const auto* particle = dynamic_cast<const ParticleItem*>(p)) {
         auto* formFactor = particle->formFactorItem();
-        auto* ffLabel = addLabel<FormfactorsCatalog>(label, "Formfactor", formFactor);
+        auto* ffLabel = addLabel<FormfactorCatalog>(label, "Formfactor", formFactor);
         for (auto* d : formFactor->geometryProperties())
             addParameterItem(ffLabel, *d);
     } else if (const auto* particleComposition = dynamic_cast<const CompoundItem*>(p)) {
@@ -280,7 +280,7 @@ ParameterLabelItem* ParameterTreeBuilder::addItemWithParticles(ParameterLabelIte
         addParameterItem(label, meso->vectorC());
 
         auto* outerShape = meso->outerShapeSelection().certainItem();
-        auto* ffLabel = addLabel<FormfactorsCatalog>(label, "Outer shape", outerShape);
+        auto* ffLabel = addLabel<FormfactorCatalog>(label, "Outer shape", outerShape);
         for (auto* d : outerShape->geometryProperties())
             addParameterItem(ffLabel, *d);
 
@@ -363,8 +363,8 @@ void ParameterTreeBuilder::addBeamDistribution(ParameterLabelItem* parentLabel,
         if (withMean)
             addParameterItem(parentLabel, dn->mean(), label);
     } else {
-        const auto type = DistributionsCatalog::type(distribution);
-        const auto name = DistributionsCatalog::uiInfo(type).menuEntry;
+        const auto type = DistributionCatalog::type(distribution);
+        const auto name = DistributionCatalog::uiInfo(type).menuEntry;
         auto* item = new ParameterLabelItem(QString("%1 (%2 distribution)").arg(label).arg(name),
                                             parentLabel);
         for (auto* d : distribution->distributionValues(withMean))
diff --git a/GUI/Model/Mask/MasksSet.cpp b/GUI/Model/Mask/MasksSet.cpp
index 03558948cc5b68fc080135680bab613aae8ef948..569e30c2e67e0d09d4249433360465a3e88a45ef 100644
--- a/GUI/Model/Mask/MasksSet.cpp
+++ b/GUI/Model/Mask/MasksSet.cpp
@@ -14,7 +14,7 @@
 
 #include "GUI/Model/Mask/MasksSet.h"
 #include "GUI/Model/Descriptor/PolyItem.h"
-#include "GUI/Model/Mask/MasksCatalog.h"
+#include "GUI/Model/Mask/MaskCatalog.h"
 #include "GUI/Model/Util/UtilXML.h"
 
 namespace {
@@ -44,7 +44,7 @@ void MasksSet::writeTo(QXmlStreamWriter* w) const
 
     for (const MaskItem* t : *this) {
         w->writeStartElement(Tag::Mask);
-        PolyItem<MasksCatalog>::writeItemTo(t, w);
+        PolyItem<MaskCatalog>::writeItemTo(t, w);
         w->writeEndElement();
     }
 }
@@ -60,7 +60,7 @@ void MasksSet::readFrom(QXmlStreamReader* r)
         QString tag = r->name().toString();
 
         if (tag == Tag::Mask) {
-            add_item(PolyItem<MasksCatalog>().readItemFrom(r));
+            add_item(PolyItem<MaskCatalog>().readItemFrom(r));
             XML::gotoEndElementOfTag(r, tag);
 
         } else
diff --git a/GUI/Model/Sample/CompoundItem.cpp b/GUI/Model/Sample/CompoundItem.cpp
index 064e50ee10e036cc966195df91e3ced7079a90c0..20e07185a9fd8bc7a1b876e5b03348945e7fff28 100644
--- a/GUI/Model/Sample/CompoundItem.cpp
+++ b/GUI/Model/Sample/CompoundItem.cpp
@@ -18,8 +18,8 @@
 #include "GUI/Model/Descriptor/PolyItem.h"
 #include "GUI/Model/Sample/CoreAndShellItem.h"
 #include "GUI/Model/Sample/MesocrystalItem.h"
+#include "GUI/Model/Sample/ParticleCatalog.h"
 #include "GUI/Model/Sample/ParticleItem.h"
-#include "GUI/Model/Sample/ParticlesCatalog.h"
 #include "Sample/Particle/Compound.h"
 #include "Sample/Particle/CoreAndShell.h"
 #include "Sample/Particle/Mesocrystal.h"
@@ -67,7 +67,7 @@ void CompoundItem::writeTo(QXmlStreamWriter* w) const
     // particles
     for (auto* t : m_particles) {
         w->writeStartElement(Tag::Particle);
-        PolyItem<ParticlesCatalog>::writeItemTo(t, w);
+        PolyItem<ParticleCatalog>::writeItemTo(t, w);
         w->writeEndElement();
     }
     XML::writeTaggedValue(w, Tag::ExpandCompoundGroupbox, expandCompound);
@@ -86,7 +86,7 @@ void CompoundItem::readFrom(QXmlStreamReader* r)
             XML::readBaseElement<ItemWithParticles>(r, tag, this);
         else if (tag == Tag::Particle) {
             MaterialsSet* dummy = nullptr;
-            m_particles.push_back(PolyItem<ParticlesCatalog>().readItemFrom(r, dummy)); // TODO
+            m_particles.push_back(PolyItem<ParticleCatalog>().readItemFrom(r, dummy)); // TODO
             XML::gotoEndElementOfTag(r, tag);
         } else if (tag == Tag::ExpandCompoundGroupbox)
             expandCompound = XML::readTaggedBool(r, tag);
diff --git a/GUI/Model/Sample/InterferenceItems.h b/GUI/Model/Sample/InterferenceItems.h
index 133e6e7faec6927698de6b71393ba199c74dacc8..87fe33269c670887588dfbece7c2f5dc2c83e686 100644
--- a/GUI/Model/Sample/InterferenceItems.h
+++ b/GUI/Model/Sample/InterferenceItems.h
@@ -19,8 +19,8 @@
 #include "GUI/Model/Descriptor/PolyItem.h"
 #include "GUI/Model/Sample/Lattice2DCatalog.h"
 #include "GUI/Model/Sample/Lattice2DItems.h"
+#include "GUI/Model/Sample/ProfileCatalogs.h"
 #include "GUI/Model/Sample/ProfileItems.h"
-#include "GUI/Model/Sample/ProfilesCatalogs.h"
 #include <memory>
 
 class IInterference;
diff --git a/GUI/Model/Sample/MesocrystalItem.cpp b/GUI/Model/Sample/MesocrystalItem.cpp
index a38742dfff80eca25f44379c0f3ef62c65d53bee..eb9455bed371cb4f18268ad60155f35b9bb29834 100644
--- a/GUI/Model/Sample/MesocrystalItem.cpp
+++ b/GUI/Model/Sample/MesocrystalItem.cpp
@@ -57,8 +57,8 @@ MesocrystalItem::MesocrystalItem(const MaterialsSet*)
     m_vectorC.init("Third lattice vector (nm)", "Coordinates of the third lattice vector",
                    "vectorC");
 
-    m_outer_shape.initWithArgs("Outer Shape", "", FormfactorsCatalog::Type::Box);
-    m_basis_particle.initWithArgs("Basis", "", ParticlesCatalog::Type::Particle, nullptr);
+    m_outer_shape.initWithArgs("Outer Shape", "", FormfactorCatalog::Type::Box);
+    m_basis_particle.initWithArgs("Basis", "", ParticleCatalog::Type::Particle, nullptr);
 }
 
 void MesocrystalItem::writeTo(QXmlStreamWriter* w) const
diff --git a/GUI/Model/Sample/MesocrystalItem.h b/GUI/Model/Sample/MesocrystalItem.h
index 1a96613c9ef3fd407b96f5673e459bce64ce0acf..2469b05f588d43361e5efb5a93b2bc95e50c7506 100644
--- a/GUI/Model/Sample/MesocrystalItem.h
+++ b/GUI/Model/Sample/MesocrystalItem.h
@@ -17,10 +17,10 @@
 
 #include "GUI/Model/Descriptor/PolyItem.h"
 #include "GUI/Model/Descriptor/VectorProperty.h"
+#include "GUI/Model/Sample/FormfactorCatalog.h"
 #include "GUI/Model/Sample/FormfactorItems.h"
-#include "GUI/Model/Sample/FormfactorsCatalog.h"
 #include "GUI/Model/Sample/ItemWithParticles.h"
-#include "GUI/Model/Sample/ParticlesCatalog.h"
+#include "GUI/Model/Sample/ParticleCatalog.h"
 #include "Sample/Lattice/Lattice3D.h"
 #include <memory>
 
@@ -44,7 +44,7 @@ public:
     std::unique_ptr<IFormfactor> getOuterShape() const;
     template <typename T> T* setOuterShapeType();
 
-    PolyItem<FormfactorsCatalog>& outerShapeSelection() { return m_outer_shape; }
+    PolyItem<FormfactorCatalog>& outerShapeSelection() { return m_outer_shape; }
     void setOuterShape(FormfactorItem* p) { m_outer_shape.setCertainItem(p); }
 
     ItemWithParticles* basisItem() const { return m_basis_particle.certainItem(); }
@@ -70,8 +70,8 @@ private:
     VectorProperty m_vectorA;
     VectorProperty m_vectorB;
     VectorProperty m_vectorC;
-    PolyItem<FormfactorsCatalog> m_outer_shape;
-    PolyItem<ParticlesCatalog> m_basis_particle;
+    PolyItem<FormfactorCatalog> m_outer_shape;
+    PolyItem<ParticleCatalog> m_basis_particle;
 };
 
 template <typename T> T* MesocrystalItem::setOuterShapeType()
diff --git a/GUI/Model/Sample/ParticleItem.cpp b/GUI/Model/Sample/ParticleItem.cpp
index 1ed6a3ed7c51f522c13cfb2da11fd47dbfb9eece..bfc615d1748178ab7fae091b0617e73ae313f5e3 100644
--- a/GUI/Model/Sample/ParticleItem.cpp
+++ b/GUI/Model/Sample/ParticleItem.cpp
@@ -40,7 +40,7 @@ ParticleItem::ParticleItem(const MaterialsSet* materials)
     : ItemWithMaterial(materials)
     , ItemWithParticles(abundance_tooltip, position_tooltip)
 {
-    m_form_factor.initWithArgs("Form Factor", "", FormfactorsCatalog::Type::Sphere);
+    m_form_factor.initWithArgs("Form Factor", "", FormfactorCatalog::Type::Sphere);
     m_form_factor.setCertainItem(new CylinderItem);
 }
 
diff --git a/GUI/Model/Sample/ParticleItem.h b/GUI/Model/Sample/ParticleItem.h
index ca60791a54f97cc2969865fbbe1c74d6e13a2d21..93071f8b019866554997fa290398a83694967ee6 100644
--- a/GUI/Model/Sample/ParticleItem.h
+++ b/GUI/Model/Sample/ParticleItem.h
@@ -16,8 +16,8 @@
 #define BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLEITEM_H
 
 #include "GUI/Model/Descriptor/PolyItem.h"
+#include "GUI/Model/Sample/FormfactorCatalog.h"
 #include "GUI/Model/Sample/FormfactorItems.h"
-#include "GUI/Model/Sample/FormfactorsCatalog.h"
 #include "GUI/Model/Sample/ItemWithMaterial.h"
 #include "GUI/Model/Sample/ItemWithParticles.h"
 #include <memory>
@@ -41,7 +41,7 @@ public:
     bool expandParticle = true;
 
 private:
-    PolyItem<FormfactorsCatalog> m_form_factor;
+    PolyItem<FormfactorCatalog> m_form_factor;
 };
 
 template <typename T> T* ParticleItem::setFormfactorItemType()
diff --git a/GUI/Model/Sample/ParticleLayoutItem.cpp b/GUI/Model/Sample/ParticleLayoutItem.cpp
index 263f761728b79e87b9d624ac5fc433a806291691..5f48cffc71ac25aa4e847449a630447fe297db3e 100644
--- a/GUI/Model/Sample/ParticleLayoutItem.cpp
+++ b/GUI/Model/Sample/ParticleLayoutItem.cpp
@@ -18,8 +18,8 @@
 #include "GUI/Model/Sample/CompoundItem.h"
 #include "GUI/Model/Sample/Lattice2DItems.h"
 #include "GUI/Model/Sample/MesocrystalItem.h"
+#include "GUI/Model/Sample/ParticleCatalog.h"
 #include "GUI/Model/Sample/ParticleItem.h"
-#include "GUI/Model/Sample/ParticlesCatalog.h"
 
 namespace {
 namespace Tag {
@@ -112,7 +112,7 @@ void ParticleLayoutItem::writeTo(QXmlStreamWriter* w) const
     // particles
     for (auto* t : m_particles) {
         w->writeStartElement(Tag::Particle);
-        PolyItem<ParticlesCatalog>::writeItemTo(t, w);
+        PolyItem<ParticleCatalog>::writeItemTo(t, w);
         w->writeEndElement();
     }
     XML::writeTaggedValue(w, Tag::ExpandLayoutGroupbox, expandParticleLayout);
@@ -133,7 +133,7 @@ void ParticleLayoutItem::readFrom(QXmlStreamReader* r)
         } else if (tag == Tag::InterferenceFunction)
             XML::readTaggedElement(r, tag, m_interference);
         else if (tag == Tag::Particle) {
-            m_particles.push_back(PolyItem<ParticlesCatalog>().readItemFrom(r, m_materials));
+            m_particles.push_back(PolyItem<ParticleCatalog>().readItemFrom(r, m_materials));
             XML::gotoEndElementOfTag(r, tag);
         } else if (tag == Tag::ExpandLayoutGroupbox)
             expandParticleLayout = XML::readTaggedBool(r, tag);
diff --git a/GUI/Model/Sample/ProfilesCatalogs.cpp b/GUI/Model/Sample/ProfileCatalogs.cpp
similarity index 97%
rename from GUI/Model/Sample/ProfilesCatalogs.cpp
rename to GUI/Model/Sample/ProfileCatalogs.cpp
index 70999f5dcc1b8769a5dd6841afaa382c009e5550..a566fd5a18a17b36d2bf8b4fa446c9e044f62a82 100644
--- a/GUI/Model/Sample/ProfilesCatalogs.cpp
+++ b/GUI/Model/Sample/ProfileCatalogs.cpp
@@ -2,7 +2,7 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Sample/ProfilesCatalogs.cpp
+//! @file      GUI/Model/Sample/ProfileCatalogs.cpp
 //! @brief     Implements classes Profile1DItemCatalog, Profile2DItemCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
@@ -12,7 +12,7 @@
 //
 //  ************************************************************************************************
 
-#include "GUI/Model/Sample/ProfilesCatalogs.h"
+#include "GUI/Model/Sample/ProfileCatalogs.h"
 #include "Base/Util/Assert.h"
 #include "GUI/Model/Sample/ProfileItems.h"
 
diff --git a/GUI/Model/Sample/ProfilesCatalogs.h b/GUI/Model/Sample/ProfileCatalogs.h
similarity index 90%
rename from GUI/Model/Sample/ProfilesCatalogs.h
rename to GUI/Model/Sample/ProfileCatalogs.h
index 3abee2c2c8adbc2aca9f0adc2c4a4d2e1162e60d..fd420d8efd8291c60d12b4f2028f0201c9277bf7 100644
--- a/GUI/Model/Sample/ProfilesCatalogs.h
+++ b/GUI/Model/Sample/ProfileCatalogs.h
@@ -2,7 +2,7 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Sample/ProfilesCatalogs.h
+//! @file      GUI/Model/Sample/ProfileCatalogs.h
 //! @brief     Defines classes Profile1DItemCatalog, Profile2DItemCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
@@ -12,8 +12,8 @@
 //
 //  ************************************************************************************************
 
-#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_PROFILESCATALOGS_H
-#define BORNAGAIN_GUI_MODEL_SAMPLE_PROFILESCATALOGS_H
+#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_PROFILECATALOGS_H
+#define BORNAGAIN_GUI_MODEL_SAMPLE_PROFILECATALOGS_H
 
 #include "GUI/Model/Type/UiInfo.h"
 #include <QVector>
@@ -75,5 +75,4 @@ public:
     static Type type(const BaseType* item);
 };
 
-
-#endif // BORNAGAIN_GUI_MODEL_SAMPLE_PROFILESCATALOGS_H
+#endif // BORNAGAIN_GUI_MODEL_SAMPLE_PROFILECATALOGS_H
diff --git a/GUI/Model/Sim/InstrumentItems.cpp b/GUI/Model/Sim/InstrumentItems.cpp
index 153cec89d399bbd196ffb85a46b29f4c8ceef2fc..6e42a68a4d714ef4227d773f6416b0496356922b 100644
--- a/GUI/Model/Sim/InstrumentItems.cpp
+++ b/GUI/Model/Sim/InstrumentItems.cpp
@@ -36,8 +36,8 @@
 #include "GUI/Model/File/DatafileItem.h"
 #include "GUI/Model/Sample/SampleItem.h"
 #include "GUI/Model/Sim/BackgroundItems.h"
+#include "GUI/Model/Sim/InstrumentCatalog.h"
 #include "GUI/Model/Sim/InstrumentItems.h"
-#include "GUI/Model/Sim/InstrumentsCatalog.h"
 #include "GUI/Model/Util/Backup.h"
 #include "Param/Distrib/Distributions.h"
 #include "Sample/Multilayer/MultiLayer.h"
@@ -107,8 +107,8 @@ InstrumentItem::~InstrumentItem() = default;
 
 InstrumentItem* InstrumentItem::clone() const
 {
-    const auto type = InstrumentsCatalog::type(this);
-    InstrumentItem* copy = InstrumentsCatalog::create(type);
+    const auto type = InstrumentCatalog::type(this);
+    InstrumentItem* copy = InstrumentCatalog::create(type);
     GUI::Util::copyContents(this, copy);
     copy->setId(QUuid::createUuid().toString());
     return copy;
diff --git a/GUI/Model/Sim/InstrumentXML.cpp b/GUI/Model/Sim/InstrumentXML.cpp
index 398dae89732ac4a9795bc1de43eb6ce57f05791c..ab8d32a404f5fea63730072ea711b8510c33ccf8 100644
--- a/GUI/Model/Sim/InstrumentXML.cpp
+++ b/GUI/Model/Sim/InstrumentXML.cpp
@@ -15,8 +15,8 @@
 #include "GUI/Model/Sim/InstrumentXML.h"
 #include "Base/Util/Assert.h"
 #include "GUI/Model/Descriptor/PolyItem.h"
+#include "GUI/Model/Sim/InstrumentCatalog.h"
 #include "GUI/Model/Sim/InstrumentItems.h"
-#include "GUI/Model/Sim/InstrumentsCatalog.h"
 #include "GUI/Model/Util/UtilXML.h"
 #include <QFile>
 
@@ -39,11 +39,11 @@ void InstrumentXML::save(const QString& fname, const InstrumentItem* t)
     w.writeStartDocument();
     w.writeStartElement(XML_ROOT_TAG);
 
-    const uint typeIndex = static_cast<uint>(InstrumentsCatalog::type(t));
+    const uint typeIndex = static_cast<uint>(InstrumentCatalog::type(t));
     XML::writeAttribute(&w, XML::Attrib::type, typeIndex);
     // The next line allows to see the name of item type in XML. May be skipped while reading.
     XML::writeAttribute(&w, XML::Attrib::name,
-                        InstrumentsCatalog::uiInfo(InstrumentsCatalog::type(t)).menuEntry);
+                        InstrumentCatalog::uiInfo(InstrumentCatalog::type(t)).menuEntry);
 
     t->writeTo(&w);
     w.writeEndElement();
@@ -76,8 +76,8 @@ InstrumentItem* InstrumentXML::load(const QString& fname)
     if (found_version != 1)
         throw std::runtime_error("Unsupported version of instrument element");
     const uint typeIndex = XML::readUInt(&r, XML::Attrib::type);
-    const auto type = static_cast<typename InstrumentsCatalog::Type>(typeIndex);
-    t = InstrumentsCatalog::create(type);
+    const auto type = static_cast<typename InstrumentCatalog::Type>(typeIndex);
+    t = InstrumentCatalog::create(type);
     ASSERT(t);
     t->readFrom(&r);
 
diff --git a/GUI/Model/Sim/InstrumentsSet.cpp b/GUI/Model/Sim/InstrumentsSet.cpp
index ade6b8a11001e55a1ba55a6bb2b0b4416abb4787..512c2777a84d725cc21a6ddea249ad4d41cd9f08 100644
--- a/GUI/Model/Sim/InstrumentsSet.cpp
+++ b/GUI/Model/Sim/InstrumentsSet.cpp
@@ -13,7 +13,7 @@
 //  ************************************************************************************************
 
 #include "GUI/Model/Sim/InstrumentsSet.h"
-#include "GUI/Model/Sim/InstrumentsCatalog.h"
+#include "GUI/Model/Sim/InstrumentCatalog.h"
 
 namespace {
 namespace Tag {
@@ -48,7 +48,7 @@ void InstrumentsSet::readFrom(QXmlStreamReader* r)
     while (r->readNextStartElement()) {
         QString tag = r->name().toString();
         if (tag == Tag::Instrument) {
-            add_item(PolyItem<InstrumentsCatalog>().readItemFrom(r));
+            add_item(PolyItem<InstrumentCatalog>().readItemFrom(r));
             XML::gotoEndElementOfTag(r, tag);
         } else if (tag == Tag::CurrentIndex)
             setCurrentIndex(XML::readTaggedSize(r, tag));
diff --git a/GUI/View/Sample/CompoundForm.cpp b/GUI/View/Sample/CompoundForm.cpp
index e51bb2b7e332c3f1123cd22a3da3e8c5238340b3..dc4c290b45b3a9f678776f058746dcafce9bd7ab 100644
--- a/GUI/View/Sample/CompoundForm.cpp
+++ b/GUI/View/Sample/CompoundForm.cpp
@@ -39,8 +39,8 @@ CompoundForm::CompoundForm(QWidget* parent, CompoundItem* compoundItem, SampleEd
             GUI::Util::Layer::createWidgetForItemWithParticles(this, particle, false, ec));
 
     auto* btn = GUI::Util::Layer::createAddParticleButton(
-        this, [=](FormfactorsCatalog::Type type) { ec->addCompoundItem(compoundItem, type); },
-        [=](ParticlesCatalog::Type type) { ec->addCompoundItem(compoundItem, type); });
+        this, [=](FormfactorCatalog::Type type) { ec->addCompoundItem(compoundItem, type); },
+        [=](ParticleCatalog::Type type) { ec->addCompoundItem(compoundItem, type); });
 
     m_structure_editing_widgets << btn;
     m_layout->addStructureEditingRow(btn);
diff --git a/GUI/View/Sample/CoreAndShellForm.cpp b/GUI/View/Sample/CoreAndShellForm.cpp
index 17b145f11e3a8ab2ae6f56df2283b95b7aa8d91d..380fd749690c05980f154cdc94c5b056fe7efe43 100644
--- a/GUI/View/Sample/CoreAndShellForm.cpp
+++ b/GUI/View/Sample/CoreAndShellForm.cpp
@@ -15,8 +15,8 @@
 #include "GUI/View/Sample/CoreAndShellForm.h"
 #include "Base/Util/Assert.h"
 #include "GUI/Model/Sample/CoreAndShellItem.h"
+#include "GUI/Model/Sample/FormfactorCatalog.h"
 #include "GUI/Model/Sample/FormfactorItems.h"
-#include "GUI/Model/Sample/FormfactorsCatalog.h"
 #include "GUI/Model/Sample/ParticleItem.h"
 #include "GUI/View/Base/ActionFactory.h"
 #include "GUI/View/Sample/HeinzFormLayout.h"
@@ -33,12 +33,12 @@ QComboBox* createFormfactorCombo(QWidget* parent, FormfactorItem* current)
     WheelEventEater::install(combo);
     combo->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
 
-    for (const auto type : FormfactorsCatalog::types()) {
-        const auto ui = FormfactorsCatalog::uiInfo(type);
+    for (const auto type : FormfactorCatalog::types()) {
+        const auto ui = FormfactorCatalog::uiInfo(type);
         combo->addItem(QIcon(ui.iconPath), ui.menuEntry, (uint8_t)type);
     }
     combo->setMaxVisibleItems(combo->count());
-    combo->setCurrentIndex(combo->findData((uint8_t)FormfactorsCatalog::type(current)));
+    combo->setCurrentIndex(combo->findData((uint8_t)FormfactorCatalog::type(current)));
 
     return combo;
 }
@@ -140,7 +140,7 @@ void CoreAndShellForm::onCoreComboChanged()
     while (core.layout->rowCount() > 1)
         core.layout->removeRow(1);
 
-    const auto type = (FormfactorsCatalog::Type)core.formfactorCombo->currentData().toUInt();
+    const auto type = (FormfactorCatalog::Type)core.formfactorCombo->currentData().toUInt();
     m_ec->setCoreFormfactor(this, type);
 }
 
@@ -149,7 +149,7 @@ void CoreAndShellForm::onShellComboChanged()
     while (shell.layout->rowCount() > 1)
         shell.layout->removeRow(1);
 
-    const auto type = (FormfactorsCatalog::Type)shell.formfactorCombo->currentData().toUInt();
+    const auto type = (FormfactorCatalog::Type)shell.formfactorCombo->currentData().toUInt();
     m_ec->setShellFormfactor(this, type);
 }
 
@@ -170,7 +170,7 @@ void CoreAndShellForm::createCoreWidgets()
     QString groupTitle = "Core";
 
     if (ParticleItem* particle = m_item->coreItem()) {
-        const QString formfactor = FormfactorsCatalog::menuEntry(particle->formFactorItem());
+        const QString formfactor = FormfactorCatalog::menuEntry(particle->formFactorItem());
         groupTitle += " (" + formfactor + ")";
 
         core.layout->addBoldRow("Material", new MaterialInplaceForm(particle, m_ec));
@@ -186,7 +186,7 @@ void CoreAndShellForm::createShellWidgets()
     QString groupTitle = "Shell";
 
     if (ParticleItem* particle = m_item->shellItem()) {
-        const QString formfactor = FormfactorsCatalog::menuEntry(particle->formFactorItem());
+        const QString formfactor = FormfactorCatalog::menuEntry(particle->formFactorItem());
         groupTitle += " (" + formfactor + ")";
 
         shell.layout->addBoldRow("Material", new MaterialInplaceForm(particle, m_ec));
diff --git a/GUI/View/Sample/LayerEditorUtil.cpp b/GUI/View/Sample/LayerEditorUtil.cpp
index 58428edadf78b377b5d8840d2cb288dfdd4d8257..630d0b69bc97b760182bc87178a7899ffeb58a82 100644
--- a/GUI/View/Sample/LayerEditorUtil.cpp
+++ b/GUI/View/Sample/LayerEditorUtil.cpp
@@ -102,8 +102,8 @@ QWidget* GUI::Util::Layer::createWidgetForItemWithParticles(QWidget* parentWidge
 }
 
 QPushButton* GUI::Util::Layer::createAddParticleButton(
-    QWidget* parentWidget, std::function<void(FormfactorsCatalog::Type t)> slotAddFormfactor,
-    std::function<void(ParticlesCatalog::Type t)> slotAddParticle)
+    QWidget* parentWidget, std::function<void(FormfactorCatalog::Type t)> slotAddFormfactor,
+    std::function<void(ParticleCatalog::Type t)> slotAddParticle)
 {
     auto* btn = new QPushButton("Add particle", parentWidget);
 
@@ -113,25 +113,25 @@ QPushButton* GUI::Util::Layer::createAddParticleButton(
     const auto group = [&](const QString& title) { menuForEntries = menu->addMenu(title); };
 
     group("Hard particles");
-    for (const auto type : FormfactorsCatalog::hardParticleTypes()) {
-        const auto ui = FormfactorsCatalog::uiInfo(type);
+    for (const auto type : FormfactorCatalog::hardParticleTypes()) {
+        const auto ui = FormfactorCatalog::uiInfo(type);
         QAction* a = menuForEntries->addAction(QIcon(ui.iconPath), ui.menuEntry);
         a->setToolTip(ui.description);
         QObject::connect(a, &QAction::triggered, [=] { slotAddFormfactor(type); });
     }
 
     group("Ripples");
-    for (const auto type : FormfactorsCatalog::rippleTypes()) {
-        const auto ui = FormfactorsCatalog::uiInfo(type);
+    for (const auto type : FormfactorCatalog::rippleTypes()) {
+        const auto ui = FormfactorCatalog::uiInfo(type);
         QAction* a = menuForEntries->addAction(QIcon(ui.iconPath), ui.menuEntry);
         a->setToolTip(ui.description);
         QObject::connect(a, &QAction::triggered, [=] { slotAddFormfactor(type); });
     }
 
     group("Particle assemblies");
-    for (const auto type : {ParticlesCatalog::Type::Composition, ParticlesCatalog::Type::CoreShell,
-                            ParticlesCatalog::Type::Mesocrystal}) {
-        const auto ui = ParticlesCatalog::uiInfo(type);
+    for (const auto type : {ParticleCatalog::Type::Composition, ParticleCatalog::Type::CoreShell,
+                            ParticleCatalog::Type::Mesocrystal}) {
+        const auto ui = ParticleCatalog::uiInfo(type);
         QAction* a = menuForEntries->addAction(QIcon(ui.iconPath), ui.menuEntry);
         a->setToolTip(ui.description);
         QObject::connect(a, &QAction::triggered, [=] { slotAddParticle(type); });
diff --git a/GUI/View/Sample/LayerEditorUtil.h b/GUI/View/Sample/LayerEditorUtil.h
index 456463e87c773a502f6f962e850efb2c6948f5a5..3ea37a56fa2e10fa43abf98dd8c3b7ccbf6d38c4 100644
--- a/GUI/View/Sample/LayerEditorUtil.h
+++ b/GUI/View/Sample/LayerEditorUtil.h
@@ -16,8 +16,8 @@
 #define BORNAGAIN_GUI_VIEW_SAMPLE_LAYEREDITORUTIL_H
 
 #include "GUI/Model/Descriptor/DoubleProperty.h"
-#include "GUI/Model/Sample/FormfactorsCatalog.h"
-#include "GUI/Model/Sample/ParticlesCatalog.h"
+#include "GUI/Model/Sample/FormfactorCatalog.h"
+#include "GUI/Model/Sample/ParticleCatalog.h"
 #include <QGridLayout>
 #include <QPushButton>
 #include <functional>
@@ -50,8 +50,8 @@ QWidget* createWidgetForItemWithParticles(QWidget* parentWidget,
 
 QPushButton*
 createAddParticleButton(QWidget* parentWidget,
-                        std::function<void(FormfactorsCatalog::Type t)> slotAddFormfactor,
-                        std::function<void(ParticlesCatalog::Type t)> slotAddParticle);
+                        std::function<void(FormfactorCatalog::Type t)> slotAddFormfactor,
+                        std::function<void(ParticleCatalog::Type t)> slotAddParticle);
 
 QVector<QColor> predefinedLayerColors();
 
diff --git a/GUI/View/Sample/MesocrystalForm.cpp b/GUI/View/Sample/MesocrystalForm.cpp
index 282b95b362ec8c1f1e40fba973e3976059803ab8..3ea9bc44e6c35c03fa688dfdce296cab9d23144e 100644
--- a/GUI/View/Sample/MesocrystalForm.cpp
+++ b/GUI/View/Sample/MesocrystalForm.cpp
@@ -78,17 +78,17 @@ QComboBox* MesocrystalForm::createBasisCombo(QWidget* parent, ItemWithParticles*
     combo->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
 
     uint32_t currentData = 0;
-    for (auto type : FormfactorsCatalog::types()) {
-        const auto ui = FormfactorsCatalog::uiInfo(type);
+    for (auto type : FormfactorCatalog::types()) {
+        const auto ui = FormfactorCatalog::uiInfo(type);
         combo->addItem(QIcon(ui.iconPath), ui.menuEntry, static_cast<uint32_t>(type));
         if (auto* p = dynamic_cast<ParticleItem*>(current))
-            if (FormfactorsCatalog::type(p->formFactorItem()) == type)
+            if (FormfactorCatalog::type(p->formFactorItem()) == type)
                 currentData = static_cast<uint32_t>(type);
     }
-    for (auto type : ParticlesCatalog::assemblyTypes()) {
-        const auto ui = ParticlesCatalog::uiInfo(type);
+    for (auto type : ParticleCatalog::assemblyTypes()) {
+        const auto ui = ParticleCatalog::uiInfo(type);
         combo->addItem(QIcon(ui.iconPath), ui.menuEntry, 1000 + static_cast<uint32_t>(type));
-        if (ParticlesCatalog::type(current) == type)
+        if (ParticleCatalog::type(current) == type)
             currentData = 1000 + static_cast<uint32_t>(type);
     }
 
@@ -108,9 +108,9 @@ void MesocrystalForm::onBasisComboChanged()
 
     const auto currentData = m_basis_combo->currentData().toUInt();
     if (currentData < 1000)
-        m_ec->setMesocrystalBasis(this, static_cast<FormfactorsCatalog::Type>(currentData));
+        m_ec->setMesocrystalBasis(this, static_cast<FormfactorCatalog::Type>(currentData));
     else
-        m_ec->setMesocrystalBasis(this, static_cast<ParticlesCatalog::Type>(currentData - 1000));
+        m_ec->setMesocrystalBasis(this, static_cast<ParticleCatalog::Type>(currentData - 1000));
 }
 
 void MesocrystalForm::createBasisWidgets()
diff --git a/GUI/View/Sample/ParticleForm.cpp b/GUI/View/Sample/ParticleForm.cpp
index 7840d69ea2b220bbfc3152667909e483996e7f7a..3889cf9710344e73bd416a6e82aff9a3587d3b0c 100644
--- a/GUI/View/Sample/ParticleForm.cpp
+++ b/GUI/View/Sample/ParticleForm.cpp
@@ -13,8 +13,8 @@
 //  ************************************************************************************************
 
 #include "GUI/View/Sample/ParticleForm.h"
+#include "GUI/Model/Sample/FormfactorCatalog.h"
 #include "GUI/Model/Sample/FormfactorItems.h"
-#include "GUI/Model/Sample/FormfactorsCatalog.h"
 #include "GUI/Model/Sample/ParticleItem.h"
 #include "GUI/View/Base/ActionFactory.h"
 #include "GUI/View/Sample/HeinzFormLayout.h"
@@ -25,7 +25,7 @@ namespace {
 
 QString titleOfItem(const ParticleItem* particleItem)
 {
-    return "Particle (" + FormfactorsCatalog::menuEntry(particleItem->formFactorItem()) + ")";
+    return "Particle (" + FormfactorCatalog::menuEntry(particleItem->formFactorItem()) + ")";
 }
 
 } // namespace
diff --git a/GUI/View/Sample/ParticleLayoutForm.cpp b/GUI/View/Sample/ParticleLayoutForm.cpp
index da8172ab465dff768ce78c0fc1d1e15d4bd5814f..7c80926427f2084b723f91e072dac30c1b6dcaa1 100644
--- a/GUI/View/Sample/ParticleLayoutForm.cpp
+++ b/GUI/View/Sample/ParticleLayoutForm.cpp
@@ -51,8 +51,8 @@ ParticleLayoutForm::ParticleLayoutForm(LayerForm* form, ParticleLayoutItem* t,
             GUI::Util::Layer::createWidgetForItemWithParticles(this, particle, true, ec));
 
     auto* btn = GUI::Util::Layer::createAddParticleButton(
-        this, [=](FormfactorsCatalog::Type type) { ec->addParticleLayoutItem(t, type); },
-        [=](ParticlesCatalog::Type type) { ec->addParticleLayoutItem(t, type); });
+        this, [=](FormfactorCatalog::Type type) { ec->addParticleLayoutItem(t, type); },
+        [=](ParticleCatalog::Type type) { ec->addParticleLayoutItem(t, type); });
     m_structure_editing_widgets << btn;
     m_layout->addStructureEditingRow(btn);
 
diff --git a/GUI/View/Sample/SampleEditorController.cpp b/GUI/View/Sample/SampleEditorController.cpp
index 48ca38d5624f262d2d6dcffe7c035a249566436c..dcd9bba671fa2e387b8c2b763e2b4dcb9bf91cd3 100644
--- a/GUI/View/Sample/SampleEditorController.cpp
+++ b/GUI/View/Sample/SampleEditorController.cpp
@@ -177,7 +177,7 @@ void SampleEditorController::onParticleLayoutAdded(ParticleLayoutItem* layout,
 }
 
 void SampleEditorController::addParticleLayoutItem(ParticleLayoutItem* layout,
-                                                   FormfactorsCatalog::Type formFactorType)
+                                                   FormfactorCatalog::Type formFactorType)
 {
     auto* newParticle = createAndInitItem(formFactorType);
     layout->addItemWithParticleSelection(newParticle);
@@ -185,7 +185,7 @@ void SampleEditorController::addParticleLayoutItem(ParticleLayoutItem* layout,
 }
 
 void SampleEditorController::addParticleLayoutItem(ParticleLayoutItem* layout,
-                                                   ParticlesCatalog::Type type)
+                                                   ParticleCatalog::Type type)
 {
     auto* newItem = createAndInitItem(type);
     layout->addItemWithParticleSelection(newItem);
@@ -194,7 +194,7 @@ void SampleEditorController::addParticleLayoutItem(ParticleLayoutItem* layout,
 
 void SampleEditorController::duplicateItemWithParticles(ItemWithParticles* item)
 {
-    auto type = ParticlesCatalog::type(item);
+    auto type = ParticleCatalog::type(item);
     auto* newItem = createAndInitItem(type);
     GUI::Util::copyContents(item, newItem);
 
@@ -221,7 +221,7 @@ void SampleEditorController::onParticleCompoundAdded(CompoundItem* composition,
 }
 
 void SampleEditorController::addCompoundItem(CompoundItem* compositionItem,
-                                             ParticlesCatalog::Type type)
+                                             ParticleCatalog::Type type)
 {
     auto* newItem = createAndInitItem(type);
     compositionItem->addItemWithParticleSelection(newItem);
@@ -229,7 +229,7 @@ void SampleEditorController::addCompoundItem(CompoundItem* compositionItem,
 }
 
 void SampleEditorController::addCompoundItem(CompoundItem* compositionItem,
-                                             FormfactorsCatalog::Type formFactorType)
+                                             FormfactorCatalog::Type formFactorType)
 {
     auto* newParticle = createAndInitItem(formFactorType);
     compositionItem->addItemWithParticleSelection(newParticle);
@@ -237,17 +237,17 @@ void SampleEditorController::addCompoundItem(CompoundItem* compositionItem,
 }
 
 ItemWithParticles*
-SampleEditorController::createAndInitItem(FormfactorsCatalog::Type formFactorType) const
+SampleEditorController::createAndInitItem(FormfactorCatalog::Type formFactorType) const
 {
     auto* newParticle = new ParticleItem(materialModel());
-    newParticle->setFormfactor(FormfactorsCatalog::create(formFactorType));
+    newParticle->setFormfactor(FormfactorCatalog::create(formFactorType));
     newParticle->setMaterial(materialModel()->defaultParticleMaterialItem());
     return newParticle;
 }
 
-ItemWithParticles* SampleEditorController::createAndInitItem(ParticlesCatalog::Type type) const
+ItemWithParticles* SampleEditorController::createAndInitItem(ParticleCatalog::Type type) const
 {
-    auto* newItem = ParticlesCatalog::create(type, materialModel());
+    auto* newItem = ParticleCatalog::create(type, materialModel());
 
     if (auto* p = dynamic_cast<ItemWithMaterial*>(newItem))
         p->setMaterial(materialModel()->defaultMaterialItem());
@@ -267,27 +267,27 @@ ItemWithParticles* SampleEditorController::createAndInitItem(ParticlesCatalog::T
 }
 
 void SampleEditorController::setCoreFormfactor(CoreAndShellForm* widget,
-                                               FormfactorsCatalog::Type type)
+                                               FormfactorCatalog::Type type)
 {
     auto* particleCoreShell = widget->coreShellItem();
 
     if (particleCoreShell->coreItem() == nullptr)
         particleCoreShell->createCoreItem(materialModel());
 
-    particleCoreShell->coreItem()->setFormfactor(FormfactorsCatalog::create(type));
+    particleCoreShell->coreItem()->setFormfactor(FormfactorCatalog::create(type));
     widget->createCoreWidgets();
     emit modified();
 }
 
 void SampleEditorController::setShellFormfactor(CoreAndShellForm* widget,
-                                                FormfactorsCatalog::Type type)
+                                                FormfactorCatalog::Type type)
 {
     auto* particleCoreShell = widget->coreShellItem();
 
     if (particleCoreShell->shellItem() == nullptr)
         particleCoreShell->createShellItem(materialModel());
 
-    particleCoreShell->shellItem()->setFormfactor(FormfactorsCatalog::create(type));
+    particleCoreShell->shellItem()->setFormfactor(FormfactorCatalog::create(type));
     widget->createShellWidgets();
     emit modified();
 }
@@ -405,7 +405,7 @@ void SampleEditorController::onStoppedToMoveLayer(QWidget* widgetToMove,
 }
 
 void SampleEditorController::setMesocrystalBasis(MesocrystalForm* widget,
-                                                 ParticlesCatalog::Type type)
+                                                 ParticleCatalog::Type type)
 {
     auto* meso = widget->mesocrystalItem();
     meso->setBasisItem(createAndInitItem(type));
@@ -414,7 +414,7 @@ void SampleEditorController::setMesocrystalBasis(MesocrystalForm* widget,
 }
 
 void SampleEditorController::setMesocrystalBasis(MesocrystalForm* widget,
-                                                 FormfactorsCatalog::Type type)
+                                                 FormfactorCatalog::Type type)
 {
     auto* meso = widget->mesocrystalItem();
     meso->setBasisItem(createAndInitItem(type));
diff --git a/GUI/View/Sample/SampleEditorController.h b/GUI/View/Sample/SampleEditorController.h
index c145947c0e4728e4784e74dc653f3331bc9d6ef3..9cd2574d89720b1c284e258019ffa72d01e9fe0e 100644
--- a/GUI/View/Sample/SampleEditorController.h
+++ b/GUI/View/Sample/SampleEditorController.h
@@ -15,8 +15,8 @@
 #ifndef BORNAGAIN_GUI_VIEW_SAMPLE_SAMPLEEDITORCONTROLLER_H
 #define BORNAGAIN_GUI_VIEW_SAMPLE_SAMPLEEDITORCONTROLLER_H
 
-#include "GUI/Model/Sample/FormfactorsCatalog.h"
-#include "GUI/Model/Sample/ParticlesCatalog.h"
+#include "GUI/Model/Sample/FormfactorCatalog.h"
+#include "GUI/Model/Sample/ParticleCatalog.h"
 #include <QObject>
 
 class CompoundItem;
@@ -74,23 +74,23 @@ public:
     void removeLayoutItem(LayerForm* layerForm, ParticleLayoutItem* layout);
 
     void onParticleLayoutAdded(ParticleLayoutItem* layout, ItemWithParticles* newItem);
-    void addParticleLayoutItem(ParticleLayoutItem* layout, ParticlesCatalog::Type type);
-    void addParticleLayoutItem(ParticleLayoutItem* layout, FormfactorsCatalog::Type type);
+    void addParticleLayoutItem(ParticleLayoutItem* layout, ParticleCatalog::Type type);
+    void addParticleLayoutItem(ParticleLayoutItem* layout, FormfactorCatalog::Type type);
     ParticleLayoutItem* parentLayoutItem(ItemWithParticles* item);
 
     void onParticleCompoundAdded(CompoundItem* composition, ItemWithParticles* newItem);
-    void addCompoundItem(CompoundItem* composition, ParticlesCatalog::Type type);
-    void addCompoundItem(CompoundItem* composition, FormfactorsCatalog::Type type);
+    void addCompoundItem(CompoundItem* composition, ParticleCatalog::Type type);
+    void addCompoundItem(CompoundItem* composition, FormfactorCatalog::Type type);
     CompoundItem* parentCompoundItem(ItemWithParticles* item);
 
     void duplicateItemWithParticles(ItemWithParticles* item);
     void removeParticle(ItemWithParticles* item);
 
-    void setCoreFormfactor(CoreAndShellForm* widget, FormfactorsCatalog::Type type);
-    void setShellFormfactor(CoreAndShellForm* widget, FormfactorsCatalog::Type type);
+    void setCoreFormfactor(CoreAndShellForm* widget, FormfactorCatalog::Type type);
+    void setShellFormfactor(CoreAndShellForm* widget, FormfactorCatalog::Type type);
 
-    void setMesocrystalBasis(MesocrystalForm* widget, ParticlesCatalog::Type type);
-    void setMesocrystalBasis(MesocrystalForm* widget, FormfactorsCatalog::Type type);
+    void setMesocrystalBasis(MesocrystalForm* widget, ParticleCatalog::Type type);
+    void setMesocrystalBasis(MesocrystalForm* widget, FormfactorCatalog::Type type);
     void selectInterference(InterferenceForm* widget, int newIndex);
     void setIntegrateOverXi(LatticeTypeSelectionForm* widget, bool value);
 
@@ -116,8 +116,8 @@ signals:
     void modified();
 
 private:
-    ItemWithParticles* createAndInitItem(FormfactorsCatalog::Type formFactorType) const;
-    ItemWithParticles* createAndInitItem(ParticlesCatalog::Type itemType) const;
+    ItemWithParticles* createAndInitItem(FormfactorCatalog::Type formFactorType) const;
+    ItemWithParticles* createAndInitItem(ParticleCatalog::Type itemType) const;
 
     SampleItem* m_sample_item;
     SampleForm* m_sample_form;
diff --git a/GUI/Model/Beam/DistributionsCatalog.cpp b/GUI/Model/Beam/DistributionCatalog.cpp
similarity index 83%
rename from GUI/Model/Beam/DistributionsCatalog.cpp
rename to GUI/Model/Beam/DistributionCatalog.cpp
index 140425988dfa291c7c336c2653d2f54b857438d7..c211b1fd3c8150387c7182a8213d8a08e82558ad 100644
--- a/GUI/Model/Beam/DistributionsCatalog.cpp
+++ b/GUI/Model/Beam/DistributionCatalog.cpp
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Beam/DistributionsCatalog.cpp
 //! @brief     Implements class DistributionsCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,11 +12,11 @@
 //
 //  ************************************************************************************************
 
-#include "GUI/Model/Beam/DistributionsCatalog.h"
+#include "GUI/Model/Beam/DistributionCatalog.h"
 #include "Base/Util/Assert.h"
 #include "GUI/Model/Beam/DistributionItems.h"
 
-DistributionItem* DistributionsCatalog::create(Type type)
+DistributionItem* DistributionCatalog::create(Type type)
 {
     switch (type) {
     case Type::None:
@@ -37,18 +37,18 @@ DistributionItem* DistributionsCatalog::create(Type type)
     ASSERT_NEVER;
 }
 
-QVector<DistributionsCatalog::Type> DistributionsCatalog::types()
+QVector<DistributionCatalog::Type> DistributionCatalog::types()
 {
     return {Type::None,      Type::Gate,   Type::Lorentz,  Type::Gaussian,
             Type::LogNormal, Type::Cosine, Type::Trapezoid};
 }
 
-QVector<DistributionsCatalog::Type> DistributionsCatalog::symmetricTypes()
+QVector<DistributionCatalog::Type> DistributionCatalog::symmetricTypes()
 {
     return {Type::None, Type::Lorentz, Type::Gaussian, Type::Cosine};
 }
 
-UiInfo DistributionsCatalog::uiInfo(Type type)
+UiInfo DistributionCatalog::uiInfo(Type type)
 {
     switch (type) {
     case Type::None:
@@ -69,7 +69,7 @@ UiInfo DistributionsCatalog::uiInfo(Type type)
     ASSERT_NEVER;
 }
 
-DistributionsCatalog::Type DistributionsCatalog::type(const DistributionItem* item)
+DistributionCatalog::Type DistributionCatalog::type(const DistributionItem* item)
 {
     if (dynamic_cast<const DistributionNoneItem*>(item))
         return Type::None;
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Beam/DistributionsCatalog.cpp
-//! @brief     Implements class DistributionsCatalog.
+//! @file      GUI/Model/Beam/DistributionCatalog.cpp
+//! @brief     Implements class DistributionCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Beam/DistributionsCatalog.h b/GUI/Model/Beam/DistributionCatalog.h
similarity index 81%
rename from GUI/Model/Beam/DistributionsCatalog.h
rename to GUI/Model/Beam/DistributionCatalog.h
index 85a5252ab139c368506739398bfe9b7c17d11a88..a1e84b7347ab1e7d3cbf08aefbaa772b2a73dedd 100644
--- a/GUI/Model/Beam/DistributionsCatalog.h
+++ b/GUI/Model/Beam/DistributionCatalog.h
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Beam/DistributionsCatalog.h
 //! @brief     Defines class DistributionsCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,15 +12,15 @@
 //
 //  ************************************************************************************************
 
-#ifndef BORNAGAIN_GUI_MODEL_BEAM_DISTRIBUTIONSCATALOG_H
-#define BORNAGAIN_GUI_MODEL_BEAM_DISTRIBUTIONSCATALOG_H
+#ifndef BORNAGAIN_GUI_MODEL_BEAM_DISTRIBUTIONCATALOG_H
+#define BORNAGAIN_GUI_MODEL_BEAM_DISTRIBUTIONCATALOG_H
 
 #include "GUI/Model/Type/UiInfo.h"
 #include <QVector>
 
 class DistributionItem;
 
-class DistributionsCatalog {
+class DistributionCatalog {
 public:
     // used in PolyItem<Catalog>
     using BaseType = DistributionItem;
@@ -51,4 +51,4 @@ public:
     static Type type(const DistributionItem* item);
 };
 
-#endif // BORNAGAIN_GUI_MODEL_BEAM_DISTRIBUTIONSCATALOG_H
+#endif // BORNAGAIN_GUI_MODEL_BEAM_DISTRIBUTIONCATALOG_H
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Beam/DistributionsCatalog.h
-//! @brief     Defines class DistributionsCatalog.
+//! @file      GUI/Model/Beam/DistributionCatalog.h
+//! @brief     Defines class DistributionCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Mask/MasksCatalog.cpp b/GUI/Model/Mask/MaskCatalog.cpp
similarity index 88%
rename from GUI/Model/Mask/MasksCatalog.cpp
rename to GUI/Model/Mask/MaskCatalog.cpp
index 9820e15bf09f6ad6b33e83d4f3e39d639f3469d1..4399e64e8d96420956a6c877adab9119897d2655 100644
--- a/GUI/Model/Mask/MasksCatalog.cpp
+++ b/GUI/Model/Mask/MaskCatalog.cpp
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Mask/MasksCatalog.cpp
 //! @brief     Implements class MasksCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,11 +12,11 @@
 //
 //  ************************************************************************************************
 
-#include "GUI/Model/Mask/MasksCatalog.h"
+#include "GUI/Model/Mask/MaskCatalog.h"
 #include "Base/Util/Assert.h"
 #include "GUI/Model/Mask/MaskItems.h"
 
-MaskItem* MasksCatalog::create(Type type)
+MaskItem* MaskCatalog::create(Type type)
 {
     switch (type) {
     case Type::RegionOfInterest:
@@ -37,13 +37,13 @@ MaskItem* MasksCatalog::create(Type type)
     ASSERT_NEVER;
 }
 
-QVector<MasksCatalog::Type> MasksCatalog::types()
+QVector<MaskCatalog::Type> MaskCatalog::types()
 {
     return {Type::RegionOfInterest, Type::Rectangle, Type::Polygon, Type::VerticalLine,
             Type::HorizontalLine,   Type::MaskAll,   Type::Ellipse};
 }
 
-UiInfo MasksCatalog::uiInfo(Type type)
+UiInfo MaskCatalog::uiInfo(Type type)
 {
     switch (type) {
     case Type::RegionOfInterest:
@@ -64,7 +64,7 @@ UiInfo MasksCatalog::uiInfo(Type type)
     ASSERT_NEVER;
 }
 
-MasksCatalog::Type MasksCatalog::type(const MaskItem* item)
+MaskCatalog::Type MaskCatalog::type(const MaskItem* item)
 {
     if (dynamic_cast<const RegionOfInterestItem*>(item)) // has to be before test for Rectangle!
         return Type::RegionOfInterest;
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Mask/MasksCatalog.cpp
-//! @brief     Implements class MasksCatalog.
+//! @file      GUI/Model/Mask/MaskCatalog.cpp
+//! @brief     Implements class MaskCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Mask/MasksCatalog.h b/GUI/Model/Mask/MaskCatalog.h
similarity index 83%
rename from GUI/Model/Mask/MasksCatalog.h
rename to GUI/Model/Mask/MaskCatalog.h
index c1cacd36f513a15a2b3f686d7802b320f21c65e1..c865e37fad48906a8acf2efe44f12dbd4d1a41fa 100644
--- a/GUI/Model/Mask/MasksCatalog.h
+++ b/GUI/Model/Mask/MaskCatalog.h
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Mask/MasksCatalog.h
 //! @brief     Defines class MasksCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,15 +12,15 @@
 //
 //  ************************************************************************************************
 
-#ifndef BORNAGAIN_GUI_MODEL_MASK_MASKSCATALOG_H
-#define BORNAGAIN_GUI_MODEL_MASK_MASKSCATALOG_H
+#ifndef BORNAGAIN_GUI_MODEL_MASK_MASKCATALOG_H
+#define BORNAGAIN_GUI_MODEL_MASK_MASKCATALOG_H
 
 #include "GUI/Model/Type/UiInfo.h"
 #include <QVector>
 
 class MaskItem;
 
-class MasksCatalog {
+class MaskCatalog {
 public:
     // used in PolyItem<Catalog>
     using BaseType = MaskItem;
@@ -49,4 +49,4 @@ public:
     static Type type(const MaskItem* item);
 };
 
-#endif // BORNAGAIN_GUI_MODEL_MASK_MASKSCATALOG_H
+#endif // BORNAGAIN_GUI_MODEL_MASK_MASKCATALOG_H
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Mask/MasksCatalog.h
-//! @brief     Defines class MasksCatalog.
+//! @file      GUI/Model/Mask/MaskCatalog.h
+//! @brief     Defines class MaskCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Sample/FormfactorsCatalog.cpp b/GUI/Model/Sample/FormfactorCatalog.cpp
similarity index 94%
rename from GUI/Model/Sample/FormfactorsCatalog.cpp
rename to GUI/Model/Sample/FormfactorCatalog.cpp
index 81928b1f4fb8e4cfd86df7b283ae9162bd3b77c1..8d41bc62fad475c870c76812026d2be6baf3d1ae 100644
--- a/GUI/Model/Sample/FormfactorsCatalog.cpp
+++ b/GUI/Model/Sample/FormfactorCatalog.cpp
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Sample/FormfactorsCatalog.cpp
 //! @brief     Implements class FormfactorsCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,11 +12,11 @@
 //
 //  ************************************************************************************************
 
-#include "GUI/Model/Sample/FormfactorsCatalog.h"
+#include "GUI/Model/Sample/FormfactorCatalog.h"
 #include "Base/Util/Assert.h"
 #include "GUI/Model/Sample/FormfactorItems.h"
 
-FormfactorItem* FormfactorsCatalog::create(Type type)
+FormfactorItem* FormfactorCatalog::create(Type type)
 {
 #define CREATE(t)                                                                                  \
     case Type::t:                                                                                  \
@@ -61,7 +61,7 @@ FormfactorItem* FormfactorsCatalog::create(Type type)
 #undef CREATE
 }
 
-QVector<FormfactorsCatalog::Type> FormfactorsCatalog::types()
+QVector<FormfactorCatalog::Type> FormfactorCatalog::types()
 {
     return {Type::BarGauss,
             Type::BarLorentz,
@@ -96,7 +96,7 @@ QVector<FormfactorsCatalog::Type> FormfactorsCatalog::types()
             Type::TruncatedSpheroid};
 }
 
-QVector<FormfactorsCatalog::Type> FormfactorsCatalog::hardParticleTypes()
+QVector<FormfactorCatalog::Type> FormfactorCatalog::hardParticleTypes()
 {
     return {Type::Bipyramid4,
             Type::Box,
@@ -124,14 +124,14 @@ QVector<FormfactorsCatalog::Type> FormfactorsCatalog::hardParticleTypes()
 }
 
 
-QVector<FormfactorsCatalog::Type> FormfactorsCatalog::rippleTypes()
+QVector<FormfactorCatalog::Type> FormfactorCatalog::rippleTypes()
 {
     return {Type::BarGauss,          Type::BarLorentz,          Type::Box,
             Type::CosineRippleBox,   Type::CosineRippleGauss,   Type::CosineRippleLorentz,
             Type::SawtoothRippleBox, Type::SawtoothRippleGauss, Type::SawtoothRippleLorentz};
 }
 
-UiInfo FormfactorsCatalog::uiInfo(Type type)
+UiInfo FormfactorCatalog::uiInfo(Type type)
 {
     switch (type) {
     case Type::Pyramid2:
@@ -260,7 +260,7 @@ UiInfo FormfactorsCatalog::uiInfo(Type type)
     }
 }
 
-FormfactorsCatalog::Type FormfactorsCatalog::type(const FormfactorItem* item)
+FormfactorCatalog::Type FormfactorCatalog::type(const FormfactorItem* item)
 {
     ASSERT(item);
 
@@ -303,7 +303,7 @@ FormfactorsCatalog::Type FormfactorsCatalog::type(const FormfactorItem* item)
     ASSERT_NEVER;
 }
 
-QString FormfactorsCatalog::menuEntry(const FormfactorItem* item)
+QString FormfactorCatalog::menuEntry(const FormfactorItem* item)
 {
     return uiInfo(type(item)).menuEntry;
 }
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Sample/FormfactorsCatalog.cpp
-//! @brief     Implements class FormfactorsCatalog.
+//! @file      GUI/Model/Sample/FormfactorCatalog.cpp
+//! @brief     Implements class FormfactorCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Sample/FormfactorsCatalog.h b/GUI/Model/Sample/FormfactorCatalog.h
similarity index 87%
rename from GUI/Model/Sample/FormfactorsCatalog.h
rename to GUI/Model/Sample/FormfactorCatalog.h
index 982f6d248312ffe5a2cea1e45ee68a7a64ae8043..60f033f35ef84906274b652b7a4bc85f46499fc5 100644
--- a/GUI/Model/Sample/FormfactorsCatalog.h
+++ b/GUI/Model/Sample/FormfactorCatalog.h
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Sample/FormfactorsCatalog.h
 //! @brief     Defines class FormfactorsCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,15 +12,15 @@
 //
 //  ************************************************************************************************
 
-#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_FORMFACTORSCATALOG_H
-#define BORNAGAIN_GUI_MODEL_SAMPLE_FORMFACTORSCATALOG_H
+#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_FORMFACTORCATALOG_H
+#define BORNAGAIN_GUI_MODEL_SAMPLE_FORMFACTORCATALOG_H
 
 #include "GUI/Model/Type/UiInfo.h"
 #include <QVector>
 
 class FormfactorItem;
 
-class FormfactorsCatalog {
+class FormfactorCatalog {
 public:
     // used in PolyItem<Catalog>
     using BaseType = FormfactorItem;
@@ -78,4 +78,4 @@ public:
     static QString menuEntry(const FormfactorItem* item);
 };
 
-#endif // BORNAGAIN_GUI_MODEL_SAMPLE_FORMFACTORSCATALOG_H
+#endif // BORNAGAIN_GUI_MODEL_SAMPLE_FORMFACTORCATALOG_H
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Sample/FormfactorsCatalog.h
-//! @brief     Defines class FormfactorsCatalog.
+//! @file      GUI/Model/Sample/FormfactorCatalog.h
+//! @brief     Defines class FormfactorCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Sample/ParticlesCatalog.cpp b/GUI/Model/Sample/ParticleCatalog.cpp
similarity index 82%
rename from GUI/Model/Sample/ParticlesCatalog.cpp
rename to GUI/Model/Sample/ParticleCatalog.cpp
index b542b12361c8b32cdd48fb0e4364f0d0876c41e9..25afa2b3348d17a139e7822b4c5b046e2d00b893 100644
--- a/GUI/Model/Sample/ParticlesCatalog.cpp
+++ b/GUI/Model/Sample/ParticleCatalog.cpp
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Sample/ParticlesCatalog.cpp
 //! @brief     Implements class ParticlesCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,14 +12,14 @@
 //
 //  ************************************************************************************************
 
-#include "GUI/Model/Sample/ParticlesCatalog.h"
+#include "GUI/Model/Sample/ParticleCatalog.h"
 #include "Base/Util/Assert.h"
 #include "GUI/Model/Sample/CompoundItem.h"
 #include "GUI/Model/Sample/CoreAndShellItem.h"
 #include "GUI/Model/Sample/MesocrystalItem.h"
 #include "GUI/Model/Sample/ParticleItem.h"
 
-ItemWithParticles* ParticlesCatalog::create(Type type, const MaterialsSet* materials)
+ItemWithParticles* ParticleCatalog::create(Type type, const MaterialsSet* materials)
 {
     switch (type) {
     case Type::Particle:
@@ -35,17 +35,17 @@ ItemWithParticles* ParticlesCatalog::create(Type type, const MaterialsSet* mater
     }
 }
 
-QVector<ParticlesCatalog::Type> ParticlesCatalog::types()
+QVector<ParticleCatalog::Type> ParticleCatalog::types()
 {
     return {Type::Particle, Type::Composition, Type::CoreShell, Type::Mesocrystal};
 }
 
-QVector<ParticlesCatalog::Type> ParticlesCatalog::assemblyTypes()
+QVector<ParticleCatalog::Type> ParticleCatalog::assemblyTypes()
 {
     return {Type::Composition, Type::CoreShell, Type::Mesocrystal};
 }
 
-UiInfo ParticlesCatalog::uiInfo(Type type)
+UiInfo ParticleCatalog::uiInfo(Type type)
 {
     switch (type) {
     case Type::Particle:
@@ -64,7 +64,7 @@ UiInfo ParticlesCatalog::uiInfo(Type type)
     }
 }
 
-ParticlesCatalog::Type ParticlesCatalog::type(const ItemWithParticles* item)
+ParticleCatalog::Type ParticleCatalog::type(const ItemWithParticles* item)
 {
     ASSERT(item);
 
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Sample/ParticlesCatalog.cpp
-//! @brief     Implements class ParticlesCatalog.
+//! @file      GUI/Model/Sample/ParticleCatalog.cpp
+//! @brief     Implements class ParticleCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Sample/ParticlesCatalog.h b/GUI/Model/Sample/ParticleCatalog.h
similarity index 81%
rename from GUI/Model/Sample/ParticlesCatalog.h
rename to GUI/Model/Sample/ParticleCatalog.h
index 11928856fe22d15aa43ffe440317cbac5cb2f344..52fa65408d7647e8d0e5dba365f28fc9182f1d5b 100644
--- a/GUI/Model/Sample/ParticlesCatalog.h
+++ b/GUI/Model/Sample/ParticleCatalog.h
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Sample/ParticlesCatalog.h
 //! @brief     Defines class ParticlesCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,8 +12,8 @@
 //
 //  ************************************************************************************************
 
-#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLESCATALOG_H
-#define BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLESCATALOG_H
+#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLECATALOG_H
+#define BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLECATALOG_H
 
 #include "GUI/Model/Type/UiInfo.h"
 #include <QVector>
@@ -21,7 +21,7 @@
 class ItemWithParticles;
 class MaterialsSet;
 
-class ParticlesCatalog {
+class ParticleCatalog {
 public:
     // used in PolyItem<Catalog>
     using BaseType = ItemWithParticles;
@@ -44,4 +44,4 @@ public:
     static Type type(const ItemWithParticles* item);
 };
 
-#endif // BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLESCATALOG_H
+#endif // BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLECATALOG_H
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Sample/ParticlesCatalog.h
-//! @brief     Defines class ParticlesCatalog.
+//! @file      GUI/Model/Sample/ParticleCatalog.h
+//! @brief     Defines class ParticleCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Sim/InstrumentsCatalog.cpp b/GUI/Model/Sim/InstrumentCatalog.cpp
similarity index 81%
rename from GUI/Model/Sim/InstrumentsCatalog.cpp
rename to GUI/Model/Sim/InstrumentCatalog.cpp
index 879dd2f94e1c0af46e770c633af114d5bea0a6e8..61f406e4efa3670887629363fe780c24977ba3c2 100644
--- a/GUI/Model/Sim/InstrumentsCatalog.cpp
+++ b/GUI/Model/Sim/InstrumentCatalog.cpp
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Sim/InstrumentsCatalog.cpp
 //! @brief     Implements class InstrumentsCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,11 +12,11 @@
 //
 //  ************************************************************************************************
 
-#include "GUI/Model/Sim/InstrumentsCatalog.h"
+#include "GUI/Model/Sim/InstrumentCatalog.h"
 #include "Base/Util/Assert.h"
 #include "GUI/Model/Sim/InstrumentItems.h"
 
-InstrumentItem* InstrumentsCatalog::create(Type type)
+InstrumentItem* InstrumentCatalog::create(Type type)
 {
     switch (type) {
     case Type::Scatter2D:
@@ -31,12 +31,12 @@ InstrumentItem* InstrumentsCatalog::create(Type type)
     ASSERT_NEVER;
 }
 
-QVector<InstrumentsCatalog::Type> InstrumentsCatalog::types()
+QVector<InstrumentCatalog::Type> InstrumentCatalog::types()
 {
     return {Type::Scatter2D, Type::Offspec, Type::Specular, Type::Depthprobe};
 }
 
-UiInfo InstrumentsCatalog::uiInfo(Type type)
+UiInfo InstrumentCatalog::uiInfo(Type type)
 {
     switch (type) {
     case Type::Scatter2D:
@@ -51,7 +51,7 @@ UiInfo InstrumentsCatalog::uiInfo(Type type)
     ASSERT_NEVER;
 }
 
-InstrumentsCatalog::Type InstrumentsCatalog::type(const InstrumentItem* item)
+InstrumentCatalog::Type InstrumentCatalog::type(const InstrumentItem* item)
 {
     if (dynamic_cast<const Scatter2DInstrumentItem*>(item))
         return Type::Scatter2D;
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Sim/InstrumentsCatalog.cpp
-//! @brief     Implements class InstrumentsCatalog.
+//! @file      GUI/Model/Sim/InstrumentCatalog.cpp
+//! @brief     Implements class InstrumentCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Sim/InstrumentsCatalog.h b/GUI/Model/Sim/InstrumentCatalog.h
similarity index 80%
rename from GUI/Model/Sim/InstrumentsCatalog.h
rename to GUI/Model/Sim/InstrumentCatalog.h
index a78f9cae0c50a5da2d2255f1fa91c1fc70cbaa3d..7798a9f348ff8d070716a704251b35ae50cda149 100644
--- a/GUI/Model/Sim/InstrumentsCatalog.h
+++ b/GUI/Model/Sim/InstrumentCatalog.h
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Sim/InstrumentsCatalog.h
 //! @brief     Defines class InstrumentsCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,15 +12,15 @@
 //
 //  ************************************************************************************************
 
-#ifndef BORNAGAIN_GUI_MODEL_SIM_INSTRUMENTSCATALOG_H
-#define BORNAGAIN_GUI_MODEL_SIM_INSTRUMENTSCATALOG_H
+#ifndef BORNAGAIN_GUI_MODEL_SIM_INSTRUMENTCATALOG_H
+#define BORNAGAIN_GUI_MODEL_SIM_INSTRUMENTCATALOG_H
 
 #include "GUI/Model/Type/UiInfo.h"
 #include <QVector>
 
 class InstrumentItem;
 
-class InstrumentsCatalog {
+class InstrumentCatalog {
 public:
     // used in PolyItem<Catalog>
     using BaseType = InstrumentItem;
@@ -41,4 +41,4 @@ public:
     static Type type(const InstrumentItem* item);
 };
 
-#endif // BORNAGAIN_GUI_MODEL_SIM_INSTRUMENTSCATALOG_H
+#endif // BORNAGAIN_GUI_MODEL_SIM_INSTRUMENTCATALOG_H
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Sim/InstrumentsCatalog.h
-//! @brief     Defines class InstrumentsCatalog.
+//! @file      GUI/Model/Sim/InstrumentCatalog.h
+//! @brief     Defines class InstrumentCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org